@@ -20,7 +20,7 @@ from google.protobuf import timestamp_pb2
 from google.datacatalog_connectors.commons.prepare.base_entry_factory import \
     BaseEntryFactory
 
-from google.datacatalog_connectors.rdbms.scrape import constants
+from google.datacatalog_connectors.rdbms.common import constants
 
 
 class DataCatalogEntryFactory(BaseEntryFactory):
@@ -170,6 +170,19 @@ class DataCatalogEntryFactory(BaseEntryFactory):
 
     @staticmethod
     def __format_entry_column_type(source_name):
+        if isinstance(source_name, bytes):
+            # We've noticed some MySQL instances use bytes-like objects
+            # instead of `str` to specify the column types. We are using UTF-8
+            # to decode such objects when it happens because UTF-8 is the
+            # default character set for MySQL 8.0 onwards.
+            #
+            # We didn't notice similar behavior with other RDBMS but, if so,
+            # we should handle encoding as a configuration option that each
+            # RDBMS connector would have to set up. It might be exposed as a
+            # CLI arg, so users could easily change that. There is also the
+            # option to  scrape that config directly from the DB.
+            source_name = source_name.decode("utf-8")
+
         formatted_name = source_name.replace('&', '_')
         formatted_name = formatted_name.replace(':', '_')
         formatted_name = formatted_name.replace('/', '_')
