@@ -14,11 +14,23 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .sql_objects_assembled_entry_factory import\
+from .sql_objects_assembled_entry_factory import \
     SQLObjectsAssembledEntryFactory
 
-from .sql_objects_datacatalog_tag_template_factory import\
+from .sql_objects_datacatalog_entry_factory import \
+    SQLObjectsDataCatalogEntryFactory
+
+from .sql_objects_datacatalog_tag_factory import \
+    SQLObjectsDataCatalogTagFactory
+
+from .sql_objects_datacatalog_tag_template_factory import \
     SQLObjectsDataCatalogTagTemplateFactory
 
+from .sql_objects_metadata_config import \
+    SQLObjectsMetadataConfig
+
 __all__ = ('SQLObjectsAssembledEntryFactory',
-           'SQLObjectsDataCatalogTagTemplateFactory')
+           'SQLObjectsDataCatalogEntryFactory',
+           'SQLObjectsDataCatalogTagFactory',
+           'SQLObjectsDataCatalogTagTemplateFactory',
+           'SQLObjectsMetadataConfig')
